%define base_version 1.5.0
%define minor_version 1

Summary:	Mixxx is DJ software
Name:		mixxx
Version:	%{base_version}.%{minor_version}
Release:	%mkrel 3
Group:		Sound
License:	GPL
URL:		http://mixxx.sourceforge.net/
Source:		http://downloads.sourceforge.net/mixxx/%{name}-%{version}-src.tar.bz2
Patch0:		%{name}-1.5.0.1-python-config.patch
Patch1:		%{name}-1.5.0.1-djconsole-usb.patch
BuildRequires:	libsndfile-static-devel
BuildRequires:	qt3-devel 
BuildRequires:	fftw-devel 
BuildRequires:	libogg-devel 
BuildRequires:	libvorbis-devel 
BuildRequires:	jackit-devel
BuildRequires:	audiofile-devel 
BuildRequires:	libid3tag-devel 
BuildRequires:	mad-devel
BuildRequires:	mesaglu-devel 
BuildRequires:	alsa-lib-devel
BuildRequires:	portaudio-devel >= 0.19
BuildRequires:	libdjconsole-devel
BuildRequires:	libusb-devel
BuildRequires:	sed
%py_requires -d
BuildRoot:	%{_tmppath}/%{name}-%{version}-buildroot

%description
Mixxx is DJ software emulating an analog mixer with two playback devices. The
mixer includes filters, crossfader and various volume controls. Each player
accepts wave and mp3 files as input, playback speed can be adjusted during
playback, and a wheel for fast searching through a song is provided.

Mixxx can be controlled through the GUI using the mouse, or by connecting MIDI
devices to the computer. Commercial and custom build MIDI controllers can be
used. The mapping between functions and MIDI controller values are done in
text files. 

%prep
%setup -q -n %{name}-%{base_version}
%patch0 -p1 -b .orig
%patch1 -p1 -b .orig

%build
export CFLAGS="%{optflags}"
export CXXFLAGS="%{optflags}"

export QTDIR=%qt3dir

perl -p -i -e "s|QTDIR\/lib|QTDIR\/%{_lib}|g" \
	src/configure
perl -p -i -e "s|lib\/libqt-mt|%{_lib}\/libqt-mt|g" \
	src/build.definition
perl -p  -i -e 's|-ldjconsole|-ldjconsole -lusb|g' \
	src/build.definition

pushd src

./configure \
	--prefix=%{_prefix} \
	--enable-jack \
	--enable-alsa \
	--enable-djconsole \
	--enable-python 

%make
popd

%install
rm -rf %{buildroot}
pushd src

%makeinstall_std INSTALL_ROOT=%{buildroot} 
rm -fr %{buildroot}/%{_docdir}

mkdir -p %{buildroot}%{_datadir}/applications
install -m644 mixxx.desktop %{buildroot}%{_datadir}/applications

for name in 16 32 48 128; do
	mkdir -p %{buildroot}%{_iconsdir}/hicolor/${name}x${name}/apps
done

install -m644 iconsmall.png %{buildroot}%{_iconsdir}/hicolor/16x16/apps/mixxx-icon.png
install -m644 iconlarge.png %{buildroot}%{_iconsdir}/hicolor/32x32/apps/mixxx-icon.png
install -m644 iconhuge.png %{buildroot}%{_iconsdir}/hicolor/48x48/apps/mixxx-icon.png
install -m644 icon.png %{buildroot}%{_iconsdir}/hicolor/128x128/apps/mixxx-icon.png

# We don't need old icon on pixmaps
rm -rf %{buildroot}%{_datadir}/pixmaps
popd

%clean
rm -rf %{buildroot}

%post
%{update_menus}
%update_icon_cache hicolor

%postun
%{clean_menus}
%clean_icon_cache hicolor

%files
%defattr(-,root,root)
%doc COPYING README README.ALSA LICENSE README.macro HERCULES.txt 
%doc Mixxx-Manual.pdf
%{_bindir}/%{name}
%{_iconsdir}/*/*/apps/mixxx-icon.png
%dir %{_datadir}/mixxx
%{_datadir}/mixxx/*
%{_datadir}/applications/%{name}.desktop


%changelog
* Mon Aug 20 2007 Oden Eriksson <oeriksson@mandriva.com> 1.5.0.1-3mdv2008.0
+ Revision: 67909
- rebuilt against new portaudio libs

* Sun Jun 24 2007 Tomasz Pawel Gajc <tpg@mandriva.org> 1.5.0.1-2mdv2008.0
+ Revision: 43661
- fix bug #31551
- add scriplets

* Sat Jun 16 2007 Tomasz Pawel Gajc <tpg@mandriva.org> 1.5.0.1-1mdv2008.0
+ Revision: 40422
- add buildrequires on usb-devel
- fix building on x86_64
- added missing buildrequires
- spec file clean

  + Helio Chissini de Castro <helio@mandriva.com>
    - Added patch to fix djconsole build against libusb
    - New and revamped mixxx for Mandriva
    - Added support for libdjconsole \o/.
    - Added support for scripting back ( bad python config test )
    - Removed ols debian like menu
    - Added proper desktop file and their official icons
    - Restored portaudio build.
      Lets's have some fun !!


* Tue Sep 05 2006 Emmanuel Andry <eandry@mandriva.org> 1.4.2-3mdv2007.0
- xdg menu
- fix buildrequires

* Wed Jun 22 2005 Tibor Pittich <Tibor.Pittich@mandriva.org> 1.4.2-2mdk
- include README.ALSA
- use mkrel

* Fri Jan 14 2005 Tibor Pittich <Tibor.Pittich@mandrake.org> 1.4.2-1mdk
- 1.4.2
- update configure parameters

* Thu Oct 14 2004 Tibor Pittich <Tibor.Pittich@mandrake.org> 1.4.1-1mdk
- 1.4.1

* Tue Oct 12 2004 Austin Acton <austin@mandrake.org> 1.4-1mdk
- 1.4

* Tue Sep 28 2004 Franck Villaume <fvill@freesurf.fr> 1.3.2-3mdk
- more BuildRequires

* Mon Sep 27 2004 Franck Villaume <fvill@freesurf.fr> 1.3.2-2mdk
- BuildRequires

* Tue Jul 27 2004 Tibor Pittich <Tibor.Pittich@mandrake.org> 1.3.2-1mdk
- 1.3.2
- added patch to allow buid with alsa support, enabled both jack and alsa
- cosmetics, added documentation

* Sun Jul 11 2004 Michael Scherer <misc@mandrake.org> 1.2.1-3mdk 
- rebuid for new gcc (patch #0)

* Mon Mar 22 2004 Austin Acton <austin@mandrake.org> 1.2.1-2mdk
- fix installation

* Mon Feb 16 2004 Austin Acton <austin@mandrake.org> 1.2.1-1mdk
- 1.2.1

* Tue Dec 30 2003 Austin Acton <austin@linux.ca> 1.2-1mdk
- 1.2
- link to local libs

* Mon Oct 06 2003 Austin Acton <aacton@yorku.ca> 1.0-1mdk
- 1.0
- delib buildrequires

